
// MobileBackground.java
// Andrew Davison, dandrew@fivedots.coe.psu.ac.th, November 2004

/* This class offers methods for moving the background image. These
   methods are called by the MobileCamera to enhance the feeling
   of movement when the camera moves.

   The background image is set to repeat in the horizontal and 
   vertical directions, and then cropped to the size of the screen.

   The movement of the background is actually a change in the cropping
   rectangle's top-left coordinate to show a different part of the 
   background image.
*/

import javax.microedition.lcdui.*;
import javax.microedition.m3g.*;


public class MobileBackground 
{
  private final static int STEP = 3;  
  // incremental change to the cropping rectangle's x- or y- top-left coordinate

  private Background backGnd;
  private boolean isMoveable = false;

  private int width, height;   // of the screen


  public MobileBackground(Image2D backIm, int w, int h)
  {
    width = w;  height = h;
    backGnd = new Background();

    if (backIm != null) {
      backGnd.setImage( backIm );
      backGnd.setImageMode(Background.REPEAT, Background.REPEAT);
      backGnd.setCrop(backGnd.getCropX(), backGnd.getCropY(), width, height);
      isMoveable = true;
    }
    else 
      backGnd.setColor(0x00bffe); // a light blue background
  } // end of MobileBackground()


  public Background getBackground()
  {  return backGnd;  }


  // ----------------- background movement methods ----------------

  /* A movement is controlled by the STEP constant and also a factor
     input argument to the method. The STEP and factor are used to adjust
     the crop rectangle's x- or y- top-left coordinate.

     A movement only occurs if a repeating background image was created
     by the constructor (isMoveable == true).

     These methods are called from the MobileCamera object when the 
     camera moves.
  */

  public void moveRight(int factor)
  { if (isMoveable)
      backGnd.setCrop(backGnd.getCropX()-(STEP*factor), 
                      backGnd.getCropY(), width, height);
  } 

  public void moveLeft(int factor)
  { if (isMoveable)
      backGnd.setCrop(backGnd.getCropX()+(STEP*factor), 
                      backGnd.getCropY(), width, height);
  }

  public void moveUp(int factor)
  { if (isMoveable)
      backGnd.setCrop(backGnd.getCropX(), 
                      backGnd.getCropY()+(STEP*factor), width, height);
  }

  public void moveDown(int factor)
  { if (isMoveable)
      backGnd.setCrop(backGnd.getCropX(), 
                      backGnd.getCropY()-(STEP*factor), width, height);
  }

}  // end of MobileBackground class
