
// SkinM3G.java
// Andrew Davison, dandrew@fivedots.coe.psu.ac.th, November 2004

/* The example shows a bending coloured block placed in
   the middle of a glassy glade full of trees. The user can
   move through the scene.

   Demonstrates:
       * the use of a scene graph to build the scene (this uses
         many techniques first seen in the AnimM3G example);

       * a simple use of SkinnedMesh + animation to create
         the bending coloured block;

       * Sprite3D + transparent GIF textures for displaying trees;

       * our own Billboard class that does a similar task as Sprite3D;

       * a TiledFloor class that tiles a texture over the floor,
         making a more realistic pattern than in the Floor class;

       * a textured background of clouds that move as the camera moves
         to heighten the effect of movement. This is implemented in
         a MobileBackground class;

       * a slightly modified version of MobileCamera, first 
         introduced in the MorphM3G example.
*/

import javax.microedition.lcdui.*;
import javax.microedition.midlet.*;
import java.util.*;


public class SkinM3G extends MIDlet
{
  private static final int PERIOD = 50;   // in ms

  private Timer timer;
  private SkinCanvas skinCanvas = null;

  public SkinM3G()
  { timer = new Timer();  
    skinCanvas = new SkinCanvas(this); 
  }


  public void startApp() 
  { Display.getDisplay(this).setCurrent( skinCanvas );
    timer.schedule( new SkinTimer(), 0, PERIOD);   // tick every PERIOD ms
  }
  
  public void pauseApp() {}

  public void destroyApp(boolean unconditional) {}

  public void finishGame()
  { timer.cancel();    // stop the timer
    notifyDestroyed();  
  }


  // -------------------------------------------

  class SkinTimer extends TimerTask 
  {
    public void run() 
    { if(skinCanvas != null)
        skinCanvas.update();   // update the scene
    }
  }

} // end of SkinM3G class
